==> derby-0.0.9.tgz: package/lib/Dom.js <==
var Dom, EventDispatcher, addListener, dist, distribute, doc, domHandler, element, elements, empty, emptyEl, getMethods, getProp, htmlEscape, setMethods, win;
EventDispatcher = require('./EventDispatcher');
htmlEscape = require('./View').htmlEscape;
elements = {
  $win: win = typeof window === 'object' && window,
  $doc: doc = win.document
};
emptyEl = doc && doc.createElement('div');
element = function(id) {
  return elements[id] || (elements[id] = doc.getElementById(id));
};
empty = function() {};
getMethods = {
  attr: function(el, attr) {
    return el.getAttribute(attr);
  },
  prop: getProp = function(el, prop) {
    return el[prop];
  },
  propPolite: getProp,
  visible: empty,
  displayed: empty,
  html: function(el) {
    return el.innerHTML;
  },
  appendHtml: empty
};
setMethods = {
  attr: function(value, el, attr) {
    return el.setAttribute(attr, value);
  },
  prop: function(value, el, prop) {
    return el[prop] = value;
  },
  propPolite: function(value, el, prop) {
    if (el !== doc.activeElement) {
      return el[prop] = value;
    }
  },
  visible: function(value, el) {
    return el.style.visibility = value ? '' : 'hidden';
  },
  displayed: function(value, el) {
    return el.style.display = value ? '' : 'none';
  },
  html: function(value, el, escape) {
    return el.innerHTML = escape ? htmlEscape(value) : value;
  },
  appendHtml: function(value, el) {
    var child, _results;
    emptyEl.innerHTML = value;
    _results = [];
    while (child = emptyEl.firstChild) {
      _results.push(el.appendChild(child));
    }
    return _results;
  }
};
addListener = domHandler = empty;
dist = function(e) {
  var child, childEvent, _i, _len, _ref, _results;
  _ref = e.target.childNodes;
  _results = [];
  for (_i = 0, _len = _ref.length; _i < _len; _i++) {
    child = _ref[_i];
    if (child.nodeType !== 1) {
      return;
    }
    childEvent = Object.create(e);
    childEvent.target = child;
    domHandler(childEvent);
    _results.push(dist(childEvent));
  }
  return _results;
};
distribute = function(e) {
  var clone, key, value;
  clone = {};
  for (key in e) {
    value = e[key];
    clone[key] = value;
  }
  return dist(clone);
};
Dom = module.exports = function(model, appExports) {
  var events;
  this.events = events = new EventDispatcher({
    onBind: function(name) {
      if (!(name in events._names)) {
        return addListener(name);
      }
    },
    onTrigger: function(name, listener, targetId, e) {
      var callback, delay, el, finish, fn, id, invert, method, path, property;
      if (listener.length <= 3) {
        fn = listener[0], id = listener[1], delay = listener[2];
        callback = fn === '$dist' ? distribute : appExports[fn];
        if (!callback) {
          return;
        }
      } else {
        path = listener[0], id = listener[1], method = listener[2], property = listener[3], delay = listener[4];
        if (invert = path.charAt(0) === '!') {
          path = path.substr(1);
        }
      }
      if (id !== targetId) {
        return;
      }
      if (!(el = element(id))) {
        return false;
      }
      finish = function() {
        var value;
        value = getMethods[method](el, property);
        if (invert) {
          value = !value;
        }
        if (model.get(path) === value) {
          return;
        }
        return model.set(path, value);
      };
      if (delay != null) {
        setTimeout(callback || finish, delay, e);
      } else {
        (callback || finish)(e);
      }
    }
  });
};
Dom.prototype = {
  init: function(domEvents) {
    var events, name, _results;
    events = this.events;
    domHandler = function(e) {
      var target;
      target = e.target || (e.target = e.srcElement);
      if (target.nodeType === 3) {
        target = target.parentNode;
      }
      return events.trigger(e.type, target.id, e);
    };
    if (doc.addEventListener) {
      addListener = function(name) {
        return doc.addEventListener(name, domHandler, false);
      };
    } else if (doc.attachEvent) {
      addListener = function(name) {
        return doc.attachEvent('on' + name, function() {
          return domHandler(event);
        });
      };
    }
    events.set(domEvents);
    _results = [];
    for (name in events._names) {
      _results.push(addListener(name));
    }
    return _results;
  },
  update: function(id, method, property, value, type, local) {
    var el;
    if (!(el = element(id))) {
      return false;
    }
    if (type === 'push' && method === 'html') {
      method = 'appendHtml';
    } else if (method === 'propPolite' && local) {
      method = 'prop';
    }
    if (value === getMethods[method](el, property)) {
      return;
    }
    setMethods[method](value, el, property);
  }
};
Dom.getMethods = getMethods;
Dom.setMethods = setMethods;

==> derby-0.0.10.tgz: package/lib/Dom.js <==
var Dom, EventDispatcher, addListener, dist, distribute, doc, domHandler, element, elements, empty, emptyEl, getMethods, getProp, htmlEscape, setMethods, win;
EventDispatcher = require('./EventDispatcher');
htmlEscape = require('./View').htmlEscape;
elements = {
  $win: win = typeof window === 'object' && window,
  $doc: doc = win.document
};
emptyEl = doc && doc.createElement('div');
element = function(id) {
  return elements[id] || (elements[id] = doc.getElementById(id));
};
empty = function() {};
getMethods = {
  attr: function(el, attr) {
    return el.getAttribute(attr);
  },
  prop: getProp = function(el, prop) {
    return el[prop];
  },
  propPolite: getProp,
  visible: empty,
  displayed: empty,
  html: function(el) {
    return el.innerHTML;
  },
  appendHtml: empty
};
setMethods = {
  attr: function(value, el, attr) {
    return el.setAttribute(attr, value);
  },
  prop: function(value, el, prop) {
    return el[prop] = value;
  },
  propPolite: function(value, el, prop) {
    if (el !== doc.activeElement) {
      return el[prop] = value;
    }
  },
  visible: function(value, el) {
    return el.style.visibility = value ? '' : 'hidden';
  },
  displayed: function(value, el) {
    return el.style.display = value ? '' : 'none';
  },
  html: function(value, el, escape) {
    return el.innerHTML = escape ? htmlEscape(value) : value;
  },
  appendHtml: function(value, el) {
    var child, _results;
    emptyEl.innerHTML = value;
    _results = [];
    while (child = emptyEl.firstChild) {
      _results.push(el.appendChild(child));
    }
    return _results;
  },
  insertHtml: function(value, el, index) {
    var child, ref, _results;
    ref = el.childNodes[index];
    emptyEl.innerHTML = value;
    _results = [];
    while (child = emptyEl.firstChild) {
      _results.push(el.insertBefore(child, ref));
    }
    return _results;
  }
};
addListener = domHandler = empty;
dist = function(e) {
  var child, childEvent, _i, _len, _ref, _results;
  _ref = e.target.childNodes;
  _results = [];
  for (_i = 0, _len = _ref.length; _i < _len; _i++) {
    child = _ref[_i];
    if (child.nodeType !== 1) {
      return;
    }
    childEvent = Object.create(e);
    childEvent.target = child;
    domHandler(childEvent);
    _results.push(dist(childEvent));
  }
  return _results;
};
distribute = function(e) {
  var clone, key, value;
  clone = {};
  for (key in e) {
    value = e[key];
    clone[key] = value;
  }
  return dist(clone);
};
Dom = module.exports = function(model, appExports, history) {
  var events;
  this.history = history;
  this.events = events = new EventDispatcher({
    onBind: function(name) {
      if (!(name in events._names)) {
        return addListener(doc, name);
      }
    },
    onTrigger: function(name, listener, targetId, e) {
      var callback, delay, el, finish, fn, id, invert, method, path, property;
      if (listener.length <= 3) {
        fn = listener[0], id = listener[1], delay = listener[2];
        callback = fn === '$dist' ? distribute : appExports[fn];
        if (!callback) {
          return;
        }
      } else {
        path = listener[0], id = listener[1], method = listener[2], property = listener[3], delay = listener[4];
        if (invert = path.charAt(0) === '!') {
          path = path.substr(1);
        }
      }
      if (id !== targetId) {
        return;
      }
      if (!(el = element(id))) {
        return false;
      }
      finish = function() {
        var value;
        value = getMethods[method](el, property);
        if (invert) {
          value = !value;
        }
        if (model.get(path) === value) {
          return;
        }
        return model.set(path, value);
      };
      if (delay != null) {
        setTimeout(callback || finish, delay, e);
      } else {
        (callback || finish)(e);
      }
    }
  });
};
Dom.prototype = {
  init: function(domEvents) {
    var events, history, name;
    events = this.events;
    history = this.history;
    domHandler = function(e) {
      var target;
      target = e.target;
      if (target.nodeType === 3) {
        target = target.parentNode;
      }
      return events.trigger(e.type, target.id, e);
    };
    if (doc.addEventListener) {
      this.addListener = addListener = function(el, name, cb, captures) {
        if (cb == null) {
          cb = domHandler;
        }
        if (captures == null) {
          captures = false;
        }
        return el.addEventListener(name, cb, captures);
      };
    } else if (doc.attachEvent) {
      this.addListener = addListener = function(el, name, cb) {
        if (cb == null) {
          cb = domHandler;
        }
        return el.attachEvent('on' + name, function() {
          event.target || (event.target = event.srcElement);
          return cb(event);
        });
      };
    }
    events.set(domEvents);
    for (name in events._names) {
      addListener(doc, name);
    }
    addListener(doc, 'click', function(e) {
      if (e.target.href && !e.metaKey && e.which === 1) {
        return history._onClickLink(e);
      }
    });
    addListener(doc, 'submit', function(e) {
      if (e.target.tagName.toLowerCase() === 'form') {
        return history._onSubmitForm(e);
      }
    });
    return addListener(win, 'popstate', function(e) {
      return history._onPop(e);
    });
  },
  update: function(id, method, property, value, type, local) {
    var el;
    if (!(el = element(id))) {
      return false;
    }
    if (type === 'push' && method === 'html') {
      method = 'appendHtml';
    } else if (method === 'propPolite' && local) {
      method = 'prop';
    }
    if (value === getMethods[method](el, property)) {
      return;
    }
    setMethods[method](value, el, property);
  }
};
Dom.getMethods = getMethods;
Dom.setMethods = setMethods;
